Tutorial
========

This folder contains interactive tutorials that demonstrate how to build sushi chefs.

  - quickstart : basic steps for creating a channel from the README
  - nodes [TODO]
  - files [TODO]
  - exercises [TODO]


Install
-------

    pip install jupyter

then run

    cd ricecooker/docs/tutorial
    jupyter notebook



